@@ -2332,8 +2332,7 @@ special_keys(char_u *args)
     char *save_str = nb_unquote(args, NULL);
     char *tok = strtok(save_str, " ");
     char *sep;
-#define KEYBUFLEN 64
-    char keybuf[KEYBUFLEN];
+    char keybuf[64];
     char cmdbuf[256];
 
     while (tok != NULL)
@@ -2360,13 +2359,10 @@ special_keys(char_u *args)
 	    tok++;
 	}
 
-	if (strlen(tok) + i < KEYBUFLEN)
-	{
-	    strcpy(&keybuf[i], tok);
-	    vim_snprintf(cmdbuf, sizeof(cmdbuf),
-				 "<silent><%s> :nbkey %s<CR>", keybuf, keybuf);
-	    do_map(0, (char_u *)cmdbuf, NORMAL, FALSE);
-	}
+	strcpy(&keybuf[i], tok);
+	vim_snprintf(cmdbuf, sizeof(cmdbuf),
+				"<silent><%s> :nbkey %s<CR>", keybuf, keybuf);
+	do_map(0, (char_u *)cmdbuf, NORMAL, FALSE);
 	tok = strtok(NULL, " ");
     }
     vim_free(save_str);
